ASF
===

.. automodule:: mutagen.asf

.. autoclass:: mutagen.asf.ASF(filename)
    :show-inheritance:
    :members:


.. autoclass:: mutagen.asf.ASFInfo
    :show-inheritance:
    :members:
    :undoc-members:


.. autoclass:: mutagen.asf.ASFTags
    :show-inheritance:
    :members:
    :undoc-members:


.. autoclass:: mutagen.asf.error
    :show-inheritance:
    :members:
    :undoc-members:


.. autoclass:: mutagen.asf.ASFBaseAttribute()
    :members:


.. autoclass:: mutagen.asf.ASFBoolAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFGUIDAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFWordAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFDWordAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFQWordAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFBoolAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFByteArrayAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFUnicodeAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`


.. autoclass:: mutagen.asf.ASFUnicodeAttribute(value)
    :members:

    :bases: `ASFBaseAttribute`
